// Copyright (c) 2015-present Mattermost, Inc. All Rights Reserved.
// See LICENSE.txt for license information.

package assets

import _ "embed"

//go:embed bot_icon.png
var DefaultAgentProfilePicture []byte
